@@ -13,7 +13,7 @@ from typing_extensions import Literal
 
 from .dataclass_hide_default import DataclassHideDefault
 
-__version__ = "1.0.0"
+__version__ = "1.0.1"
 
 
 @dataclass(frozen=True)
@@ -180,9 +180,6 @@ class Instruction(DataclassHideDefault):
     _line_offsets_override: tuple[int, ...] = field(default=tuple())
 
 
-Arg = Union[int, "Jump", "Name", "Varname", "Constant", "Freevar", "Cellvar", "NoArg"]
-
-
 @dataclass(frozen=True)
 class Jump(DataclassHideDefault):
     """
@@ -272,6 +269,9 @@ class NoArg(DataclassHideDefault):
     _arg: int = field(default=0)
 
 
+Arg = Union[int, Jump, Name, Varname, Constant, Freevar, Cellvar, NoArg]
+
+
 # TODO: Add:
 # 6. Comparison lookup
 # 7. format value
